Switch to the CPU hotplug core state tracking and synchronization
mechanim. No functional change intended.

Signed-off-by: Thomas Gleixner <t...@linutronix.de>
Cc: Russell King <li...@armlinux.org.uk>
Cc: Arnd Bergmann <a...@arndb.de>
Cc: linux-arm-ker...@lists.infradead.org
---
 arch/arm/Kconfig           |    1 +
 arch/arm/include/asm/smp.h |    2 +-
 arch/arm/kernel/smp.c      |   18 +++++++-----------
 3 files changed, 9 insertions(+), 12 deletions(-)

--- a/arch/arm/Kconfig
+++ b/arch/arm/Kconfig
@@ -124,6 +124,7 @@ config ARM
        select HAVE_SYSCALL_TRACEPOINTS
        select HAVE_UID16
        select HAVE_VIRT_CPU_ACCOUNTING_GEN
+       select HOTPLUG_CORE_SYNC_DEAD if HOTPLUG_CPU
        select IRQ_FORCED_THREADING
        select MODULES_USE_ELF_REL
        select NEED_DMA_MAP_STATE
--- a/arch/arm/include/asm/smp.h
+++ b/arch/arm/include/asm/smp.h
@@ -64,7 +64,7 @@ extern void secondary_startup_arm(void);
 
 extern int __cpu_disable(void);
 
-extern void __cpu_die(unsigned int cpu);
+static inline void __cpu_die(unsigned int cpu) { }
 
 extern void arch_send_call_function_single_ipi(int cpu);
 extern void arch_send_call_function_ipi_mask(const struct cpumask *mask);
--- a/arch/arm/kernel/smp.c
+++ b/arch/arm/kernel/smp.c
@@ -289,15 +289,11 @@ int __cpu_disable(void)
 }
 
 /*
- * called on the thread which is asking for a CPU to be shutdown -
- * waits until shutdown has completed, or it is timed out.
+ * called on the thread which is asking for a CPU to be shutdown after the
+ * shutdown completed.
  */
-void __cpu_die(unsigned int cpu)
+void arch_cpuhp_cleanup_dead_cpu(unsigned int cpu)
 {
-       if (!cpu_wait_death(cpu, 5)) {
-               pr_err("CPU%u: cpu didn't die\n", cpu);
-               return;
-       }
        pr_debug("CPU%u: shutdown\n", cpu);
 
        clear_tasks_mm_cpumask(cpu);
@@ -337,11 +333,11 @@ void arch_cpu_idle_dead(void)
        flush_cache_louis();
 
        /*
         * Tell __cpu_die() that this CPU is now safe to dispose of.  Once
         * this returns, power and/or clocks can be removed at any point
         * from this CPU and its cache by platform_cpu_kill().
         */
-       (void)cpu_report_death();
+       cpuhp_ap_report_dead();
 
        /*
         * Ensure that the cache lines associated with that completion are
@@ -337,11 +333,11 @@ void arch_cpu_idle_dead(void)
 
        /*
-        * Tell __cpu_die() that this CPU is now safe to dispose of.  Once
-        * this returns, power and/or clocks can be removed at any point
-        * from this CPU and its cache by platform_cpu_kill().
+        * Tell cpuhp_bp_sync_dead() that this CPU is now safe to dispose
+        * of. Once this returns, power and/or clocks can be removed at
+        * any point from this CPU and its cache by platform_cpu_kill().
         */


Reply via email to